]> ruderich.org/simon Gitweb - config/dotfiles.git/commitdiff
also support xcompmgr as fallback for compton
authorSimon Ruderich <simon@ruderich.org>
Sun, 4 May 2014 20:10:26 +0000 (22:10 +0200)
committerSimon Ruderich <simon@ruderich.org>
Sun, 4 May 2014 20:10:26 +0000 (22:10 +0200)
setup.sh
xinitrc

index 368fa0b7b07b4a1e0ea1559fa7704f966a762af1..6f35e221feff17abaedd358ed1c29372f9f81c48 100755 (executable)
diff --git a/xinitrc b/xinitrc
index c4dd1c207c902d4b8945f4440849e47fdde888e2..0f32482e01fd451b21774911b4717cb5c1779c82 100755 (executable)
--- a/xinitrc
+++ b/xinitrc
@@ -151,6 +151,9 @@ fi
 # of urxvt.
 if installed compton; then
     compton &
+# xcompmgr as fallback.
+elif installed xcompmgr; then
+    xcompmgr &
 fi
--- a/setup.sh
+++ b/setup.sh
@@ -52,9 +52,9 @@ if installed X; then
          }'
     # Xresources uses ! as comment instead of #.
     sed_i 's/^#/!/' Xresources
-    # Use urxvt's pseudo-transparency if compton is not available. Better than
-    # nothing.
-    if ! installed compton; then
+    # Use urxvt's pseudo-transparency if neither compton nor xcompmgr are
+    # available. Better than nothing.
+    if ! installed compton && ! installed xcompmgr; then
         echo 'Xresources: no compton found, enabling pseudo-transparency'
         sed_i 's/^Rxvt\*background/!&/' Xresources
         sed_i 's/^!NO_COMPTON //' Xresources